summaryrefslogtreecommitdiff
path: root/distro/packages/attr.scm
diff options
context:
space:
mode:
Diffstat (limited to 'distro/packages/attr.scm')
-rw-r--r--distro/packages/attr.scm40
1 files changed, 24 insertions, 16 deletions
diff --git a/distro/packages/attr.scm b/distro/packages/attr.scm
index 8326754261..ae0d257dbe 100644
--- a/distro/packages/attr.scm
+++ b/distro/packages/attr.scm
@@ -41,23 +41,31 @@
(build-system gnu-build-system)
(arguments
`(#:phases
- (alist-replace 'install
- (lambda _
- (zero? (system* "make"
- "install"
- "install-lib"
- "install-dev")))
- (alist-replace 'check
- (lambda _
- (for-each patch-shebang
- (find-files "test" ".*"))
- (system* "make" "tests" "-C" "test")
+ (alist-cons-after
+ 'configure 'patch-makefile-SHELL
+ (lambda _
+ (patch-makefile-SHELL "include/buildmacros"))
+ (alist-replace
+ 'install
+ (lambda _
+ (zero? (system* "make"
+ "install"
+ "install-lib"
+ "install-dev")))
+ (alist-replace
+ 'check
+ (lambda _
+ ;; Use the right shell.
+ (substitute* "test/run"
+ (("/bin/sh")
+ (which "bash")))
- ;; XXX: Ignore the test result since
- ;; this is dependent on the underlying
- ;; file system.
- #t)
- %standard-phases))))
+ (system* "make" "tests" "-C" "test")
+
+ ;; XXX: Ignore the test result since this is dependent on the
+ ;; underlying file system.
+ #t)
+ %standard-phases)))))
(inputs `(("perl" ,perl)
("gettext" ,guix:gettext)))
(home-page